@@ -535,11 +535,13 @@ impl SubscriptionToken {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
-    use crate::rpc_pubsub_service::PubSubConfig;
-    use solana_ledger::genesis_utils::{create_genesis_config, GenesisConfigInfo};
-    use solana_runtime::bank::Bank;
-    use std::str::FromStr;
+    use {
+        super::*,
+        crate::rpc_pubsub_service::PubSubConfig,
+        solana_ledger::genesis_utils::{create_genesis_config, GenesisConfigInfo},
+        solana_runtime::bank::Bank,
+        std::str::FromStr,
+    };
 
     struct ControlWrapper {
         control: SubscriptionControl,
